# PROJECT : easy-wechat
# TIME : 19-3-1 上午11:07
# AUTHOR : Younger Shen
# EMAIL : younger.x.shen@gmail.com
# CELL : 13811754531
# WECHAT : 13811754531
# WEB : https://youngershen.com

VERSION = "0.0.1"



# PROJECT : easy-wechat
# TIME : 19-3-1 上午11:06
# AUTHOR : Younger Shen
# EMAIL : younger.x.shen@gmail.com
# CELL : 13811754531
# WECHAT : 13811754531
# WEB : https://youngershen.com
from setuptools import setup
from setuptools.config import read_configuration

conf = read_configuration('setup.cfg')

setup()
